h5pyViewer Python Package
=========================

This package contains classes and tools to view \*.hdf5-Files

- h5pyViewer.py: main viewer that contains the modules below
- hdfTree.py:    Tree view of a hdf5-file
- hdfGrid.py:    Grid view (Excel-like) table view of a dataset
- hdfImage.py:   image view of a dataset
- hdfAttrib.py:  attribute view of a dataset

further helper files are:  utilities.py

Locations:
 - https://pypi.python.org/pypi/h5pyViewer
 - https://github.com/ganymede42/h5pyViewer
 - https://localshop.psi.ch/packages/h5pyViewer/

Screenshots
-----------
.. image:: https://raw.github.com/ganymede42/h5pyViewer/master/screenshot/scr1.png

